==> Requirements-dropins-0.12.0.202101221536.zip: org/polarsys/capella/vp/requirements/ui/commands/RequirementsVPUICommandsPlugin.java <==
/*******************************************************************************
 * Copyright (c) 2016, 2017 THALES GLOBAL SERVICES.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 *  
 * Contributors:
 *    Thales - initial API and implementation
 *******************************************************************************/
package org.polarsys.capella.vp.requirements.ui.commands;

import org.osgi.framework.BundleContext;
import org.polarsys.capella.common.ui.services.AbstractUIActivator;

/**
 * The activator class controls the plug-in life cycle
 * @author Joao Barata
 */
public class RequirementsVPUICommandsPlugin extends AbstractUIActivator {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.polarsys.capella.vp.requirements.ui.commands"; //$NON-NLS-1$

	// The shared instance
	private static RequirementsVPUICommandsPlugin plugin;
	
	/**
	 * The constructor
	 */
	public RequirementsVPUICommandsPlugin() {
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static RequirementsVPUICommandsPlugin getDefault() {
		return plugin;
	}
}

==> Requirements-dropins-0.13.0.202208241053.zip: org/polarsys/capella/vp/requirements/ui/commands/RequirementsVPUICommandsPlugin.java <==
/*******************************************************************************
 * Copyright (c) 2016, 2017 THALES GLOBAL SERVICES.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 *  
 * Contributors:
 *    Thales - initial API and implementation
 *******************************************************************************/
package org.polarsys.capella.vp.requirements.ui.commands;

import org.eclipse.sirius.business.api.image.RichTextAttributeRegistry;
import org.osgi.framework.BundleContext;
import org.polarsys.capella.common.ui.services.AbstractUIActivator;
import org.polarsys.kitalpha.vp.requirements.Requirements.RequirementsPackage;

/**
 * The activator class controls the plug-in life cycle
 * @author Joao Barata
 */
public class RequirementsVPUICommandsPlugin extends AbstractUIActivator {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.polarsys.capella.vp.requirements.ui.commands"; //$NON-NLS-1$

	// The shared instance
	private static RequirementsVPUICommandsPlugin plugin;
	
	/**
	 * The constructor
	 */
	public RequirementsVPUICommandsPlugin() {
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		// Register ReqIfText attribute for handling of images references
        RichTextAttributeRegistry.INSTANCE.add(RequirementsPackage.eINSTANCE.getRequirement_ReqIFText());
	}

	/**
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static RequirementsVPUICommandsPlugin getDefault() {
		return plugin;
	}
}
